@@ -50,8 +50,10 @@ class SQL:
 		assert engine in SQL.ENGINES, 'Accepted engine values are: %s.' % ', '.join(SQL.ENGINES)
 		self.max_insertions, self.native_types, self.engine, self.print_queries = max_insertions, native_types, engine, print_queries
 		self._connection, self._cursor, self._initialized = {'user': user}, {}, False
-		if engine in ('mysql', 'mariadb'):
+		if engine == 'mysql':
 			self._init_mysql(charset, collation, host, use_unicode, password, db)
+		elif engine == 'mariadb':
+			self._init_mariadb(host, password, db)
 		elif engine == 'mssql':
 			self._init_mssql(host, password, db)
 		if force_init:
@@ -73,6 +75,19 @@ class SQL:
 			self._connection['db'] = db
 		self._cursor['buffered'] = True
 
+	def _init_mariadb(self, host, password, db):
+		from mariadb.constants.CLIENT import MULTI_STATEMENTS
+		from mariadb.constants.FIELD_TYPE import JSON
+		from json import loads
+
+		self._connection.update({
+			'host': host,
+			'password': password,
+			'database': db,
+			'client_flag': MULTI_STATEMENTS,
+			'converter': {JSON: loads}
+		})
+
 	def _init_mssql(self, host, password, db):
 		self._connection['server'] = host
 		if password:
@@ -91,14 +106,19 @@ class SQL:
 	def cursor(self):
 		''' Returns the open cursor and initializes the connection if required. '''
 		if not self._initialized:
-			if self.engine in ('mysql', 'mariadb'):
+			if self.engine == 'mysql':
 				try:
 					from mysql.connector import connect
 				except ModuleNotFoundError:
 					raise ModuleNotFoundError('Missing MySQL/MariaDB connector. Install a mysql client and then do `pip install mysql.connector`.')
 				if self.native_types:
 					self._connection['converter_class'] = _mysql_converter()
-			else:
+			elif self.engine == 'mariadb':
+				try:
+					from mariadb import connect
+				except ModuleNotFoundError:
+					raise ModuleNotFoundError('Missing MySQL/MariaDB connector. Install a mysql client and then do `pip install mariadb`.')
+			elif self.engine == 'mssql':
 				try:
 					from pymssql import connect
 				except ModuleNotFoundError:
@@ -116,15 +136,22 @@ class SQL:
 		error = None
 		try:
 			if self.engine == 'mysql':
-				statement = self.cursor().execute(query, params if params is not None and len(params) else None, multi)
+				statement = self.cursor().execute(query, params if params is not None and len(params) else None, multi=multi)
 				if multi:
 					try:
 						list(statement)
 					except RuntimeError:  # see https://bugs.mysql.com/bug.php?id=87818
 						pass
-			else:
+			elif self.engine == 'mariadb':
+				# mariadb connector doesn't support adding encoders at parameter level, so we have to do JSON manually; see https://github.com/mariadb-corporation/mariadb-connector-python/blob/1.1/mariadb/cursors.py#L232 https://github.com/mariadb-corporation/mariadb-connector-python/blob/80b642b8a1a3b0b41b26e8cbe188cd91c8d1233b/mariadb/mariadb_codecs.c#L1400
+				from json import dumps
+				params = [dumps(param, ensure_ascii=False, separators=(',', ':')) if isinstance(param, dict) else param for param in params] if params is not None else None
+				self.cursor().execute(query, params if params is not None and len(params) else None)
+				if multi:
+					while self.cursor().nextset(): pass
+			elif self.engine == 'mssql':
 				assert not multi, 'MS-SQL connector does not support multistatement queries.'
-				statement = self.cursor().execute(*([query] + ([params] if params else [])))
+				self.cursor().execute(*([query] + ([params] if params else [])))
 		except Exception as e:
 			error = e
 		if self._initialized and (commit or self.engine in ('mysql', 'mariadb')):
@@ -212,7 +239,7 @@ class SQL:
 	def insert(self, query: str, *params: tuple) -> int:
 		''' Inserts a row and returns its id. '''
 		self.execute(query, params, commit=True)
-		return int(self.cursor().lastrowid)
+		return None if self.cursor().lastrowid is None else int(self.cursor().lastrowid)
 
 	def insert_all(self, table: str, rows: Union[List[dict], List[tuple]], tuple_rows: bool = False, commit: bool = True) -> Optional[int]:
 		''' Insert a list of rows and returns the id of the last one. By default,
